from distutils.core import setup

setup(
    name="CliAppHelper",
    packages=["CliAppHelper"],
    version="0.1.0",
    license="MIT",
    description="CLI app helper",
    author="Sachin Bansal",
    author_email="sachinbansal94@gmail.com",
    url="https://github.com/sachinB94/cli-app-helper",
    download_url="https://github.com/sachinB94/cli-app-helper/archive/v0.1.0.tar.gz",
    keywords=["CLI", "CLI App"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
